@@ -421,6 +421,8 @@ def server_main(args=None):
         from easycluster import windows_service as servmod
     elif sys.platform.startswith('linux'):
         from easycluster import linux_service as servmod
+    elif sys.platform.startswith('sun'):
+        from easycluster import solaris_service as servmod
     else:
         servmod = None
 
@@ -469,30 +471,34 @@ def server_main(args=None):
             else:
                 return 1
 
-        if opts.install:
-            key = _core.key_from_options(opts, False)
-            if key:
-                _core.write_key_file(servmod.KEY_PATH, key, True)
-            else:
-                _core.write_key_file(servmod.KEY_PATH, _core.generate_key(), opts.overwrite)
+        try:
+            if opts.install:
+                key = _core.key_from_options(opts, False)
+                if key:
+                    _core.write_key_file(servmod.KEY_PATH, key, True)
+                else:
+                    _core.write_key_file(servmod.KEY_PATH, _core.generate_key(), opts.overwrite)
+
+                servmod.install_service()
+                if opts.start:
+                    servmod.start_service()
+                return 0
+
+            if opts.uninstall:
+                servmod.stop_service()
+                servmod.uninstall_service()
+                return 0
 
-            servmod.install_service()
             if opts.start:
                 servmod.start_service()
-            return 0
+                return 0
 
-        if opts.uninstall:
-            servmod.stop_service()
-            servmod.uninstall_service()
-            return 0
-
-        if opts.start:
-            servmod.start_service()
-            return 0
-
-        if opts.stop:
-            servmod.stop_service()
-            return 0
+            if opts.stop:
+                servmod.stop_service()
+                return 0
+        except EnvironmentError as e:
+            print(str(e), file=sys.stderr)
+            return 1
 
     if opts.generate:
         if not _core.write_key_file(opts.generate, _core.generate_key(), opts.overwrite):
